==> segatex_suite-1.6.tgz: segatex_suite-1.6/segatex_audit2allow_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOWPROCESS_H
#define SEGATEXAUDIT2ALLOWPROCESS_H

#include "segatex_audit2allow.h" 


class SegatexAudit2allowProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexAudit2allowProcess(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void audit2allow_base_process();
	void readFromStdout();
	//void updateOutputTextEdit();
	void processExited();
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	SegatexAudit2allow *selinux_audit2allow_on;
	SegatexAudit2allowProcess *selinux_audit2allow_process;
	SegatexAudit2allowProcess *selinux_audit2allow_process_progress;
	int a,b,c;
};

#endif

==> segatex_suite-2.1.tgz: segatex_suite-2.1/segatex_audit2allow_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXAUDIT2ALLOWPROCESS_H
#define SEGATEXAUDIT2ALLOWPROCESS_H

#include "segatex_audit2allow.h" 

class SegatexAudit2allow;
class CommonVar;

class SegatexAudit2allowProcess: public QDialog 
{
	Q_OBJECT
public:
	SegatexAudit2allowProcess(QWidget *parent = 0, const char *name = 0);
	SegatexAudit2allow *selinux_audit2allow_common_obj;
	int i;
public slots:
	void audit2allow_base_process(int options);
signals:
	void audit2allow_prosess_close_button_clicked();
protected:

private slots:
	void close_button_clicked();
	void readFromStdout();
	void processExited();
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QProcess *process;
	SegatexAudit2allow *selinux_audit2allow;
	SegatexAudit2allowProcess *selinux_audit2allow_process;
	int a,b,c,x,y,xx,yy,xxx,yyy,xxxx,yyyy;
};

#endif
